translate.storage.versioncontrol.svn.svn

Package translate :: Package storage :: Package versioncontrol :: Module svn :: Class svn |
[hide private]
[frames] | no frames]

# Class svn

source code

Class to manage items under revision control of Subversion.

Instance Methods | [hide private]
update(self, revision=None) update the working copy - remove local modifications if necessary | source code
commit(self, message=None, author=None) commit the file and return the given message if present | source code
getcleanfile(self, revision=None) return the content of the 'head' revision of the file | source code
Inherited from `GenericRevisionControlSystem`: `__init__` Inherited from `GenericRevisionControlSystem` (private): `_find_rcs_directory`, `_find_rcs_in_parent_directories`, `_self_check`

Class Variables | [hide private]
| RCS_METADIR = ``'``.svn``'`` The name of the metadata directory of the RCS
| SCAN_PARENTS = `False` whether to check the parent directories for the metadata directory of the RCS working copy

Method Details | [hide private]

### update(self, revision=None) | source code
update the working copy - remove local modifications if necessary Overrides: GenericRevisionControlSystem.update

### commit(self, message=None, author=None) | source code
commit the file and return the given message if present the 'author' parameter is used for revision property 'translate:author' Overrides: GenericRevisionControlSystem.commit

### getcleanfile(self, revision=None) | source code
return the content of the 'head' revision of the file Overrides: GenericRevisionControlSystem.getcleanfile